==> stealth_id-0.0.2.tar.gz: ios/Classes/CarespaceFaceEnroll.swift <==
//
//  CarespaceFaceEnroll.swift
//  risecx_stealthId
//
//  Created by Crístofer Domingues on 14/04/21.
//

import Foundation

public class CarespaceFaceEnroll {
    var service : CarespaceService
    internal var baseURL = ""
    internal var enrollmentHeader : [String : String]
    
    init(viewController: FlutterViewController, baseURL:String, apiHeader : [String : String]){
        self.service = CarespaceService(viewController:viewController, baseURL: baseURL, apiHeader: apiHeader)
        self.baseURL = baseURL.appending(":30643/sisaas/enrollment/2.1.4/")
        self.enrollmentHeader = apiHeader
    }
    
    public func enrollUser(_ userID : String, result: @escaping FlutterResult){
        print("enrollUser -- Enter")
        self.startEnrollment(userID: userID) { (startEnrollmentResult) in
            guard let serStatus:String = startEnrollmentResult["status"] as! String?, serStatus == "NOT_EXISTS" else {
                print("enrollUser -- Fail: User ID already enrolled "+startEnrollmentResult.jsonStringRepresentation!)
                result(FlutterError.init(code: startEnrollmentResult["status"] as! String , message:"User ID already enrolled", details: nil))
                return
            }
            
            self.service.takePictureFromAwareLiveness(userId: userID, transactionId: startEnrollmentResult["transactionId"] as! String) { (takePictureResult) in
                guard let  livenessInfo  = takePictureResult["livenessInfo"] as? [String : Any],
                      let video = livenessInfo["video"] as? [String:Any],
                      let autoCaptureResult = video["autocapture_result"] as? [String:Any],
                      let capturedFrame = autoCaptureResult["captured_frame"] as? String else {
                          result(FlutterError.init(code: "AWARE_LIVENESS_FAIL", message: takePictureResult["message"] as? String, details: nil))
                          return
                }
                self.onDetectionResultSuccess(startEnrollmentResult["transactionId"] as! String, capturedFrame, result)
                
            }
        }
        print("enrollUser -- Exit")
    }
    
    
    private func onDetectionResultSuccess(_ transactionId:String, _ capturedImage:String,_ result: @escaping FlutterResult){
        print("onDetectionResultSuccess -- Enter")
        
        self.detectFace(transactionId: transactionId, base64FaceImage: capturedImage) { (detectFaceResult) in
            if detectFaceResult.keys.contains("id") == false {
                print("detectFace -- Fail "+detectFaceResult.jsonStringRepresentation!)
                result(FlutterError.init(code: detectFaceResult["code"] as! String, message:detectFaceResult["message"] as? String, details: nil))
                return
            }
            self.completeEnrollment(transactionId: transactionId) { (completeEnrollmentResult) in
                guard let success = completeEnrollmentResult["success"] as! Bool?, success == true else{
                    print("completeEnrollment -- Fail"+completeEnrollmentResult.jsonStringRepresentation!)
                    result(FlutterError.init(code: completeEnrollmentResult["statusCode"] as! String, message:completeEnrollmentResult["message"] as? String, details: nil))
                    return
                }
                result(["success":true])
            }
        }
        print("onDetectionResultSuccess -- Enter")
    }
    
  
    
    private func startEnrollment(userID:String,completionHandler: @escaping (Dictionary<String, Any>) -> Void) {
        print("startEnrollment -- Enter")
        var newHeader = enrollmentHeader
        newHeader.updateValue("application/json", forKey:"Content-Type")
        
        
        var meta : [String: Any] = [

                    "meta": [

                        "location" : "",

                        "retentionCode" : "",

                        "deviceID" : ""

                    ]

                ]

                let data : [String: Any] = [

                    "data": [

                        "userID" : userID,

                        "customerCode" : "providence"

                    ]

                ]

         

        meta.merge(dict: data)
        
        self.service.webserviceCaller(baseURL+"startEnrollment", requestHeader: newHeader, httpBodyData: meta.toJson) {(response:Dictionary<String, Any>) in
            let code:String = response["code"] as? String ?? "";
            let userStatus: String = response["userStatus"] as? String ?? "";
            
            if(code == "ENROLL_USER_105" || userStatus != ""){
                print("startEnrollment -- Fail "+response.jsonStringRepresentation!)
                completionHandler(["status":"ALREADY_EXISTS"])
                return
            }
            completionHandler(["status":"NOT_EXISTS", "transactionId": response["transactionId"] as! String])
        }
        print("startEnrollment -- Exit")
    }
    
    private func detectFace(transactionId:String, base64FaceImage:String ,completionHandler: @escaping (Dictionary<String, Any>) -> Void){
        print("detectFace -- Enter")
        
     
        
        
        var meta : [String: Any] = [

                    "meta": [

                        "location" : "",

                        "retentionCode" : "",

                        "deviceID" : ""

                    ]

                ]

                let data : [String: Any] = [

                    "data": [

                        "source": transactionId,

                        "face" : base64FaceImage

                    ]

                ]

         

        meta.merge(dict: data)
        print(meta.jsonStringRepresentation!)
        
        self.service.webserviceCaller(baseURL+"detectFace", requestHeader: enrollmentHeader, httpBodyData: meta.toJson) {(response:Dictionary<String, Any>) in
           completionHandler(response)
        }
        print("detectFace -- Exit")
    }
    
    private func completeEnrollment(transactionId:String,completionHandler: @escaping (Dictionary<String, Any>) -> Void){
        print("detectFace -- Enter")
        
        var meta : [String: Any] = [

                    "meta": [

                        "location" : "",

                        "retentionCode" : "",

                        "deviceID" : ""

                    ]

                ]

                let data : [String: Any] = [

                    "data": [

                        "transactionId": transactionId,


                    ]

                ]

         

        meta.merge(dict: data)
        print(meta.jsonStringRepresentation!)
        self.service.webserviceCaller(baseURL+"completeEnrollment", requestHeader: enrollmentHeader, httpBodyData: meta.toJson) {(response:Dictionary<String, Any>) in
           completionHandler(response)
        }
        print("detectFace -- Exit")
    }
    
    private func dicToJson(_ dic:Dictionary<String,Dictionary<String,String>>) -> Data{
        do {
            let jsonData = try JSONSerialization.data(withJSONObject: dic, options: .prettyPrinted)
            return jsonData
        } catch {
            print(error.localizedDescription)
            return Data.init()
        }
    }
    
    func convertToDictionary(_ text: String) -> [String: String]? {
        if let data = text.data(using: .utf8) {
            do {
                return try JSONSerialization.jsonObject(with: data, options: []) as? [String: String]
            } catch {
                print(error.localizedDescription)
            }
        }
        return nil
    }

}

==> stealth_id-0.0.6.tar.gz: ios/Classes/CarespaceFaceEnroll.swift <==
//
//  CarespaceFaceEnroll.swift
//  risecx_stealthId
//
//  Created by Crístofer Domingues on 14/04/21.
//

import Foundation

public class CarespaceFaceEnroll {
    var service : CarespaceService
    internal var baseURL = ""
    internal var enrollmentHeader : [String : String]
    
    init(viewController: FlutterViewController, baseURL:String, apiHeader : [String : String]){
        self.service = CarespaceService(viewController:viewController, baseURL: baseURL, apiHeader: apiHeader)
        self.baseURL = baseURL.appending(":30643/sisaas/enrollment/2.2.0/")
        self.enrollmentHeader = apiHeader
    }
    
    public func enrollUser(_ userID : String, result: @escaping FlutterResult){
        print("enrollUser -- Enter")
        self.startEnrollment(userID: userID) { (startEnrollmentResult) in
            guard let serStatus:String = startEnrollmentResult["status"] as! String?, serStatus == "NOT_EXISTS" else {
                print("enrollUser -- Fail: User ID already enrolled "+startEnrollmentResult.jsonStringRepresentation!)
                result(FlutterError.init(code: startEnrollmentResult["status"] as! String , message:"User ID already enrolled", details: nil))
                return
            }
            
            self.service.takePictureFromAwareLiveness(userId: userID, transactionId: startEnrollmentResult["transactionId"] as! String) { (takePictureResult) in
                guard let  livenessInfo  = takePictureResult["livenessInfo"] as? [String : Any],
                      let video = livenessInfo["video"] as? [String:Any],
                      let autoCaptureResult = video["autocapture_result"] as? [String:Any],
                      let capturedFrame = autoCaptureResult["captured_frame"] as? String else {
                          result(FlutterError.init(code: "AWARE_LIVENESS_FAIL", message: takePictureResult["message"] as? String, details: nil))
                          return
                }
                self.onDetectionResultSuccess(startEnrollmentResult["transactionId"] as! String, capturedFrame, result)
                
            }
        }
        print("enrollUser -- Exit")
    }
    
    
    private func onDetectionResultSuccess(_ transactionId:String, _ capturedImage:String,_ result: @escaping FlutterResult){
        print("onDetectionResultSuccess -- Enter")
        
        self.detectFace(transactionId: transactionId, base64FaceImage: capturedImage) { (detectFaceResult) in
            if detectFaceResult.keys.contains("id") == false {
                print("detectFace -- Fail "+detectFaceResult.jsonStringRepresentation!)
                result(FlutterError.init(code: detectFaceResult["code"] as! String, message:detectFaceResult["message"] as? String, details: nil))
                return
            }
            self.completeEnrollment(transactionId: transactionId) { (completeEnrollmentResult) in
                guard let success = completeEnrollmentResult["success"] as! Bool?, success == true else{
                    print("completeEnrollment -- Fail"+completeEnrollmentResult.jsonStringRepresentation!)
                    result(FlutterError.init(code: completeEnrollmentResult["statusCode"] as! String, message:completeEnrollmentResult["message"] as? String, details: nil))
                    return
                }
                result(["status":true])
            }
        }
        print("onDetectionResultSuccess -- Enter")
    }
    
  
    
    private func startEnrollment(userID:String,completionHandler: @escaping (Dictionary<String, Any>) -> Void) {
        print("startEnrollment -- Enter")
        var newHeader = enrollmentHeader
        newHeader.updateValue("application/json", forKey:"Content-Type")
        
        
        var meta : [String: Any] = [

                    "meta": [

                        "location" : "",

                        "retentionCode" : "",

                        "deviceID" : ""

                    ]

                ]

                let data : [String: Any] = [

                    "data": [

                        "userID" : userID,

                        "customerCode" : "carespacedoc"

                    ]

                ]

         

        meta.merge(dict: data)
        
        self.service.webserviceCaller(baseURL+"startEnrollment", requestHeader: newHeader, httpBodyData: meta.toJson) {(response:Dictionary<String, Any>) in
            let code:String = response["code"] as? String ?? "";
            let userStatus: String = response["userStatus"] as? String ?? "";
            
            if(code == "ENROLL_USER_105" || userStatus != ""){
                print("startEnrollment -- Fail "+response.jsonStringRepresentation!)
                completionHandler(["status":"ALREADY_EXISTS"])
                return
            }
            completionHandler(["status":"NOT_EXISTS", "transactionId": response["transactionId"] as! String])
        }
        print("startEnrollment -- Exit")
    }
    
    private func detectFace(transactionId:String, base64FaceImage:String ,completionHandler: @escaping (Dictionary<String, Any>) -> Void){
        print("detectFace -- Enter")
        
     
        
        
        var meta : [String: Any] = [

                    "meta": [

                        "location" : "",

                        "retentionCode" : "",

                        "deviceID" : ""

                    ]

                ]

                let data : [String: Any] = [

                    "data": [

                        "source": transactionId,

                        "face" : base64FaceImage

                    ]

                ]

         

        meta.merge(dict: data)
        print(meta.jsonStringRepresentation!)
        
        self.service.webserviceCaller(baseURL+"detectFace", requestHeader: enrollmentHeader, httpBodyData: meta.toJson) {(response:Dictionary<String, Any>) in
           completionHandler(response)
        }
        print("detectFace -- Exit")
    }
    
    private func completeEnrollment(transactionId:String,completionHandler: @escaping (Dictionary<String, Any>) -> Void){
        print("detectFace -- Enter")
        
        var meta : [String: Any] = [

                    "meta": [

                        "location" : "",

                        "retentionCode" : "",

                        "deviceID" : ""

                    ]

                ]

                let data : [String: Any] = [

                    "data": [

                        "transactionId": transactionId,


                    ]

                ]

         

        meta.merge(dict: data)
        print(meta.jsonStringRepresentation!)
        self.service.webserviceCaller(baseURL+"completeEnrollment", requestHeader: enrollmentHeader, httpBodyData: meta.toJson) {(response:Dictionary<String, Any>) in
           completionHandler(response)
        }
        print("detectFace -- Exit")
    }
    
    private func dicToJson(_ dic:Dictionary<String,Dictionary<String,String>>) -> Data{
        do {
            let jsonData = try JSONSerialization.data(withJSONObject: dic, options: .prettyPrinted)
            return jsonData
        } catch {
            print(error.localizedDescription)
            return Data.init()
        }
    }
    
    func convertToDictionary(_ text: String) -> [String: String]? {
        if let data = text.data(using: .utf8) {
            do {
                return try JSONSerialization.jsonObject(with: data, options: []) as? [String: String]
            } catch {
                print(error.localizedDescription)
            }
        }
        return nil
    }

}
